pub(crate) struct CalibrateSessionRequest {
pub(crate) session_id: String,
pub(crate) stability: f32,
pub(crate) friction: f32,
pub(crate) logic: f32,
pub(crate) autonomy: f32,
pub(crate) trigger: String,
}Fields
session_id: Stringstability: f32friction: f32logic: f32autonomy: f32trigger: StringTrait Implementations
Sourceimpl Debug for CalibrateSessionRequest
impl Debug for CalibrateSessionRequest
Sourceimpl<'de> Deserialize<'de> for CalibrateSessionRequest
impl<'de> Deserialize<'de> for CalibrateSessionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CalibrateSessionRequest
impl JsonSchema for CalibrateSessionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CalibrateSessionRequest
impl RefUnwindSafe for CalibrateSessionRequest
impl Send for CalibrateSessionRequest
impl Sync for CalibrateSessionRequest
impl Unpin for CalibrateSessionRequest
impl UnsafeUnpin for CalibrateSessionRequest
impl UnwindSafe for CalibrateSessionRequest