pub(crate) struct CreateMonthlyRollupRequest {
pub(crate) session_id: String,
pub(crate) start_date_utc: String,
pub(crate) end_date_utc: String,
pub(crate) source_session_id: Option<String>,
pub(crate) parent_node_id: Option<String>,
pub(crate) persist: bool,
}Fields
session_id: Stringstart_date_utc: Stringend_date_utc: Stringsource_session_id: Option<String>parent_node_id: Option<String>persist: boolTrait Implementations
Sourceimpl Debug for CreateMonthlyRollupRequest
impl Debug for CreateMonthlyRollupRequest
Sourceimpl<'de> Deserialize<'de> for CreateMonthlyRollupRequest
impl<'de> Deserialize<'de> for CreateMonthlyRollupRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateMonthlyRollupRequest
impl JsonSchema for CreateMonthlyRollupRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateMonthlyRollupRequest
impl RefUnwindSafe for CreateMonthlyRollupRequest
impl Send for CreateMonthlyRollupRequest
impl Sync for CreateMonthlyRollupRequest
impl Unpin for CreateMonthlyRollupRequest
impl UnsafeUnpin for CreateMonthlyRollupRequest
impl UnwindSafe for CreateMonthlyRollupRequest