pub(crate) struct EvictNodesRequest {Show 15 fields
pub(crate) session_id: String,
pub(crate) sync_keys: Option<Vec<String>>,
pub(crate) node_ids: Option<Vec<String>>,
pub(crate) semantic_tags: Option<Vec<String>>,
pub(crate) link_rel: Option<String>,
pub(crate) link_target: Option<String>,
pub(crate) links_to_ref: Option<String>,
pub(crate) tag_prefix: Option<String>,
pub(crate) has_semantic_links: Option<bool>,
pub(crate) purge_session: Option<bool>,
pub(crate) dry_run: Option<bool>,
pub(crate) force: Option<bool>,
pub(crate) max_nodes: Option<usize>,
pub(crate) include_calibration: Option<bool>,
pub(crate) include_checkpoints: Option<bool>,
}Fields
session_id: Stringsync_keys: Option<Vec<String>>node_ids: Option<Vec<String>>link_rel: Option<String>link_target: Option<String>links_to_ref: Option<String>tag_prefix: Option<String>has_semantic_links: Option<bool>purge_session: Option<bool>dry_run: Option<bool>force: Option<bool>max_nodes: Option<usize>include_calibration: Option<bool>include_checkpoints: Option<bool>Trait Implementations
Sourceimpl Debug for EvictNodesRequest
impl Debug for EvictNodesRequest
Sourceimpl<'de> Deserialize<'de> for EvictNodesRequest
impl<'de> Deserialize<'de> for EvictNodesRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EvictNodesRequest
impl JsonSchema for EvictNodesRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EvictNodesRequest
impl RefUnwindSafe for EvictNodesRequest
impl Send for EvictNodesRequest
impl Sync for EvictNodesRequest
impl Unpin for EvictNodesRequest
impl UnsafeUnpin for EvictNodesRequest
impl UnwindSafe for EvictNodesRequest