pub(crate) struct GetContextRequest {
pub(crate) session_id: Option<String>,
pub(crate) stability: f32,
pub(crate) friction: f32,
pub(crate) logic: f32,
pub(crate) autonomy: f32,
pub(crate) limit: usize,
pub(crate) from_utc: Option<String>,
pub(crate) to_utc: Option<String>,
pub(crate) tiers: Option<Vec<String>>,
pub(crate) context_keywords: Option<Vec<String>>,
pub(crate) alpha: Option<f32>,
pub(crate) beta: Option<f32>,
}Fields
session_id: Option<String>stability: f32friction: f32logic: f32autonomy: f32limit: usizefrom_utc: Option<String>to_utc: Option<String>tiers: Option<Vec<String>>context_keywords: Option<Vec<String>>alpha: Option<f32>beta: Option<f32>Trait Implementations
Sourceimpl Debug for GetContextRequest
impl Debug for GetContextRequest
Sourceimpl<'de> Deserialize<'de> for GetContextRequest
impl<'de> Deserialize<'de> for GetContextRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetContextRequest
impl JsonSchema for GetContextRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetContextRequest
impl RefUnwindSafe for GetContextRequest
impl Send for GetContextRequest
impl Sync for GetContextRequest
impl Unpin for GetContextRequest
impl UnsafeUnpin for GetContextRequest
impl UnwindSafe for GetContextRequest