pub(crate) struct GetMoodsRequest {
pub(crate) target_mood: Option<String>,
pub(crate) blend: f32,
pub(crate) current_stability: Option<f32>,
pub(crate) current_friction: Option<f32>,
pub(crate) current_logic: Option<f32>,
pub(crate) current_autonomy: Option<f32>,
}Fields
target_mood: Option<String>blend: f32current_stability: Option<f32>current_friction: Option<f32>current_logic: Option<f32>current_autonomy: Option<f32>Trait Implementations
Sourceimpl Debug for GetMoodsRequest
impl Debug for GetMoodsRequest
Sourceimpl<'de> Deserialize<'de> for GetMoodsRequest
impl<'de> Deserialize<'de> for GetMoodsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetMoodsRequest
impl JsonSchema for GetMoodsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetMoodsRequest
impl RefUnwindSafe for GetMoodsRequest
impl Send for GetMoodsRequest
impl Sync for GetMoodsRequest
impl Unpin for GetMoodsRequest
impl UnsafeUnpin for GetMoodsRequest
impl UnwindSafe for GetMoodsRequest