pub(crate) struct ListNodesRequest {
pub(crate) limit: usize,
pub(crate) session_id: Option<String>,
pub(crate) context_keywords: Option<Vec<String>>,
}Fields
limit: usizesession_id: Option<String>context_keywords: Option<Vec<String>>Trait Implementations
Sourceimpl Debug for ListNodesRequest
impl Debug for ListNodesRequest
Sourceimpl<'de> Deserialize<'de> for ListNodesRequest
impl<'de> Deserialize<'de> for ListNodesRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListNodesRequest
impl JsonSchema for ListNodesRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListNodesRequest
impl RefUnwindSafe for ListNodesRequest
impl Send for ListNodesRequest
impl Sync for ListNodesRequest
impl Unpin for ListNodesRequest
impl UnsafeUnpin for ListNodesRequest
impl UnwindSafe for ListNodesRequest